@@ -35,9 +35,18 @@ license  : GPL-3.0+
 
 Smile config collections.
 """
-from .config import Option, Config, SConfig
+from __future__ import annotations
+
+# Standard Library
+from dataclasses import dataclass
+
+# Types
 from typing import Union
 
+# Local
+from .build import from_dataclass
+from .config import Config, Option, SConfig
+
 
 def ml_basic(*extra_options: Union[Option, SConfig]) -> Config:
     """Machine learning basic options."""
@@ -60,5 +69,18 @@ def ml_basic(*extra_options: Union[Option, SConfig]) -> Config:
     )
 
 
+@dataclass
+class Train:
+    """Train config."""
+
+    batch_size: int = 64
+
+
+@dataclass
+class ML:
+    lr: float = 0.001
+    train: Train = Train()
+
+
 if __name__ == "__main__":
-    print(ml_basic())
+    print(from_dataclass(ML(), globals()))
